Exception: OSC::VNC::InvalidPath
- Inherits:
-
StandardError
- Object
- StandardError
- OSC::VNC::InvalidPath
- Defined in:
- lib/osc/vnc/error.rb
Overview
Error used when a file or directory is invalid.
Error used when a file or directory is invalid.